==> haskell-prettyprinter-ansi-terminal-1.1.3-165-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 prettyprinter-ansi-terminal
version:              1.1.3
visibility:           public
id:                   prettyprinter-ansi-terminal-1.1.3-IuN8x6IJGfYBDtUvUAjq23
key:                  prettyprinter-ansi-terminal-1.1.3-IuN8x6IJGfYBDtUvUAjq23
license:              BSD-2-Clause
maintainer:
    Simon Jakobi <simon.jakobi@gmail.com>, David Luposchainsky <dluposchainsky at google>

author:               David Luposchainsky
homepage:             http://github.com/quchen/prettyprinter
synopsis:             ANSI terminal backend for the »prettyprinter« package.
description:          See README.md
category:             User Interfaces, Text
abi:                  5a48f55968542642feb7c74c08265352
exposed:              True
exposed-modules:
    Data.Text.Prettyprint.Doc.Render.Terminal
    Data.Text.Prettyprint.Doc.Render.Terminal.Internal
    Prettyprinter.Render.Terminal
    Prettyprinter.Render.Terminal.Internal

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/prettyprinter-ansi-terminal-1.1.3

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/prettyprinter-ansi-terminal-1.1.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-ansi-terminal
hs-libraries:         HSprettyprinter-ansi-terminal-1.1.3-IuN8x6IJGfYBDtUvUAjq23
depends:
    ansi-terminal-0.11.4-Bavr5INHzaUHF3VuHy0Lqz base-4.16.4.0
    prettyprinter-1.7.1-4X811DzHwplE7Du7oIbLHM text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-ansi-terminal/html/prettyprinter-ansi-terminal.haddock

haddock-html:         /usr/share/doc/haskell-prettyprinter-ansi-terminal/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-ansi-terminal-1.1.3-168-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 prettyprinter-ansi-terminal
version:              1.1.3
visibility:           public
id:                   prettyprinter-ansi-terminal-1.1.3-EYs3bYmruhllNLWQIiAS3
key:                  prettyprinter-ansi-terminal-1.1.3-EYs3bYmruhllNLWQIiAS3
license:              BSD-2-Clause
maintainer:
    Simon Jakobi <simon.jakobi@gmail.com>, David Luposchainsky <dluposchainsky at google>

author:               David Luposchainsky
homepage:             http://github.com/quchen/prettyprinter
synopsis:             ANSI terminal backend for the »prettyprinter« package.
description:          See README.md
category:             User Interfaces, Text
abi:                  df26eb1a0f8be544ee3c847689ab9877
exposed:              True
exposed-modules:
    Data.Text.Prettyprint.Doc.Render.Terminal
    Data.Text.Prettyprint.Doc.Render.Terminal.Internal
    Prettyprinter.Render.Terminal
    Prettyprinter.Render.Terminal.Internal

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/prettyprinter-ansi-terminal-1.1.3

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/prettyprinter-ansi-terminal-1.1.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-ansi-terminal
hs-libraries:         HSprettyprinter-ansi-terminal-1.1.3-EYs3bYmruhllNLWQIiAS3
depends:
    ansi-terminal-0.11.4-Bavr5INHzaUHF3VuHy0Lqz base-4.16.4.0
    prettyprinter-1.7.1-6Wsg7uF6NF3C9EkVjlD5S1 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-ansi-terminal/html/prettyprinter-ansi-terminal.haddock

haddock-html:         /usr/share/doc/haskell-prettyprinter-ansi-terminal/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
